@@ -1,5 +1,3 @@
-/* $XFree86: xc/programs/Xserver/hw/xfree86/common/xf86Init.c,v 3.212 2004/01/27 01:31:45 dawes Exp $ */
-/* $XdotOrg: xserver/xorg/hw/xfree86/common/xf86Init.c,v 1.37 2006/06/01 19:37:53 ajax Exp $ */
 
 /*
  * Loosely based on code bearing the following copyright:
@@ -62,9 +60,7 @@
 
 #include "compiler.h"
 
-#ifdef XFree86LOADER
 #include "loaderProcs.h"
-#endif
 #ifdef XFreeXDGA
 #include "dgaproc.h"
 #endif
@@ -114,12 +110,10 @@ extern void os2ServerVideoAccess();
 void (*xf86OSPMClose)(void) = NULL;
 #endif
 
-#ifdef XFree86LOADER
 static char *baseModules[] = {
 	"pcidata",
 	NULL
 };
-#endif
 
 /* Common pixmap formats */
 
@@ -272,10 +266,8 @@ InitOutput(ScreenInfo *pScreenInfo, int argc, char **argv)
 {
   int                    i, j, k, scr_index;
   static unsigned long   generation = 0;
-#ifdef XFree86LOADER
   char                   **modulelist;
   pointer                *optionlist;
-#endif
   screenLayoutPtr	 layout;
   Pix24Flags		 screenpix24, pix24;
   MessageType		 pix24From = X_DEFAULT;
@@ -333,7 +325,6 @@ InitOutput(ScreenInfo *pScreenInfo, int argc, char **argv)
     if (!autoconfig)
 	PostConfigInit();
 
-#ifdef XFree86LOADER
     /* Initialise the loader */
     LoaderInit();
 
@@ -377,8 +368,6 @@ InitOutput(ScreenInfo *pScreenInfo, int argc, char **argv)
     if (!xf86LoadModules(baseModules, NULL))
 	FatalError("Unable to load required base modules, Exiting...\n");
     
-#endif
-
     xf86OpenConsole();
 
     /* Do a general bus probe.  This will be a PCI probe for x86 platforms */
@@ -401,7 +390,6 @@ InitOutput(ScreenInfo *pScreenInfo, int argc, char **argv)
     /* Initialise the resource broker */
     xf86ResourceBrokerInit();
 
-#ifdef XFree86LOADER
     /* Load all modules specified explicitly in the config file */
     if ((modulelist = xf86ModulelistFromConfig(&optionlist))) {
       xf86LoadModules(modulelist, optionlist);
@@ -432,7 +420,6 @@ InitOutput(ScreenInfo *pScreenInfo, int argc, char **argv)
      * XXX Nothing keeps track of them for other modules.
      */
     /* XXX What do we do if not all of these could be loaded? */
-#endif
 
     /*
      * At this point, xf86DriverList[] is all filled in with entries for
@@ -672,12 +659,10 @@ InitOutput(ScreenInfo *pScreenInfo, int argc, char **argv)
       exit(0);
     }
 
-#ifdef XFree86LOADER
     /* Remove (unload) drivers that are not required */
     for (i = 0; i < xf86NumDrivers; i++)
 	if (xf86DriverList[i] && xf86DriverList[i]->refCount <= 0)
 	    xf86DeleteDriver(i);
-#endif
 
     /*
      * At this stage we know how many screens there are.
@@ -982,12 +967,10 @@ InitOutput(ScreenInfo *pScreenInfo, int argc, char **argv)
 #endif
   }
 
-#ifdef XFree86LOADER
     if ((serverGeneration == 1) && LoaderCheckUnresolved(LD_RESOLV_IFDONE)) {
 	/* For now, just a warning */
 	xf86Msg(X_WARNING, "Some symbols could not be resolved!\n");
     }
-#endif
 
   xf86PostScreenInit();
 
@@ -1167,9 +1150,7 @@ OsVendorInit()
   signal(SIGCHLD, SIG_DFL);	/* Need to wait for child processes */
 #endif
   OsDelayInitColors = TRUE;
-#ifdef XFree86LOADER
   loadableFonts = TRUE;
-#endif
 
   if (!beenHere)
     xf86LogInit();
@@ -1461,9 +1442,7 @@ ddxProcessArgument(int argc, char **argv, int i)
   }
   if (!strcmp(argv[i],"-ignoreABI"))
   {
-#ifdef XFree86LOADER
     LoaderSetOptions(LDR_OPT_ABI_MISMATCH_NONFATAL);
-#endif
     return 1;
   }
   if (!strcmp(argv[i],"-verbose"))
@@ -1870,9 +1849,7 @@ xf86PrintBanner()
 #endif
   ErrorF("\tBefore reporting problems, check "__VENDORDWEBSUPPORT__"\n"
 	 "\tto make sure that you have the latest version.\n");
-#ifdef XFree86LOADER
   ErrorF("Module Loader present\n");
-#endif
 }
 
 static void
@@ -1896,7 +1873,11 @@ xf86RunVtInit(void)
           FatalError("xf86RunVtInit: fork failed (%s)\n", strerror(errno));
           break;
       case 0:  /* child */
-          setuid(getuid());
+	  if (setuid(getuid()) == -1) {
+	      xf86Msg(X_ERROR, "xf86RunVtInit: setuid failed (%s)\n",
+			 strerror(errno));
+	      exit(255);
+	  }
           /* set stdin, stdout to the consoleFd */
           for (i = 0; i < 2; i++) {
             if (xf86Info.consoleFd != i) {
@@ -1915,7 +1896,6 @@ xf86RunVtInit(void)
     }
 }
 
-#ifdef XFree86LOADER
 /*
  * xf86LoadModules iterates over a list that is being passed in.
  */             
@@ -1958,8 +1938,6 @@ xf86LoadModules(char **list, pointer *optlist)
     return !failed;
 }
 
-#endif
-
 /* Pixmap format stuff */
 
 _X_EXPORT PixmapFormatPtr
