@@ -1,7 +1,3 @@
-/* $XdotOrg: xserver/xorg/hw/xfree86/loader/dixsym.c,v 1.19 2005/10/01 17:30:58 herrb Exp $ */
-/* $XFree86: xc/programs/Xserver/hw/xfree86/loader/dixsym.c,v 1.63 2003/12/03
- * 17:11:29 tsi Exp $ */
-
 /*
  * Copyright 1995-1998 by Metro Link, Inc.
  *
@@ -99,7 +95,7 @@ extern int NumCurrentSelections;
 
 /* DIX things */
 
-LOOKUP dixLookupTab[] = {
+_X_HIDDEN void *dixLookupTab[] = {
 
     /* dix */
     /* atom.c */
@@ -359,9 +355,6 @@ LOOKUP dixLookupTab[] = {
 #ifdef DBE
     SYMVAR(noDbeExtension)
 #endif
-#ifdef DPSEXT
-    SYMVAR(noDPSExtension)
-#endif
 #ifdef DPMSExtension
     SYMVAR(noDPMSExtension)
 #endif
@@ -374,9 +367,6 @@ LOOKUP dixLookupTab[] = {
 #ifdef GLXEXT
     SYMVAR(noGlxExtension)
 #endif
-#ifdef LBX
-    SYMVAR(noLbxExtension)
-#endif
 #ifdef SCREENSAVER
     SYMVAR(noScreenSaverExtension)
 #endif
@@ -476,9 +466,6 @@ LOOKUP dixLookupTab[] = {
     SYMFUNC(TimerFree)
     SYMFUNC(TimerSet)
     SYMFUNC(TimerCancel)
-#ifdef DPMSExtension
-    SYMFUNC(SetDPMSTimers)
-#endif
     /* io.c */
     SYMFUNC(WriteToClient)
     SYMFUNC(SetCriticalOutputPending)
@@ -542,6 +529,4 @@ LOOKUP dixLookupTab[] = {
     SYMFUNC(RenderEdgeInit)
     SYMFUNC(RenderLineFixedEdgeInit)
 #endif
-
-    {0, 0}
 };
