@@ -1,4 +1,3 @@
-/* $XFree86: xc/programs/Xserver/hw/xfree86/vbe/vbe.c,v 1.2tsi Exp $ */
 
 /*
  *                   XFree86 vbe module
@@ -40,11 +39,6 @@
 static unsigned char * vbeReadEDID(vbeInfoPtr pVbe);
 static Bool vbeProbeDDC(vbeInfoPtr pVbe);
 
-const char *vbe_ddcSymbols[] = {
-    "xf86InterpretEDID",
-    NULL
-};
-
 static const char vbeVersionString[] = "VBE2";
 
 vbeInfoPtr
@@ -328,8 +322,6 @@ vbeDoEDID(vbeInfoPtr pVbe, pointer pDDCModule)
 	    xf86LoadSubModule(xf86Screens[pVbe->pInt10->scrnIndex], "ddc");
 	if (!pModule)
 	    return NULL;
-
-	xf86LoaderReqSymLists(vbe_ddcSymbols, NULL);
     }
         
     DDC_data = vbeReadEDID(pVbe);
